@@ -1409,6 +1409,19 @@ struct _GIMarshallingTestsObjectClass
      */
     void  (* vfunc_multiple_out_parameters) (GIMarshallingTestsObject *self, gfloat *a, gfloat *b);
 
+    /**
+     * GIMarshallingTestsObjectClass::vfunc_one_inout_parameter:
+     * @a: (inout):
+     */
+    void  (* vfunc_one_inout_parameter) (GIMarshallingTestsObject *self, gfloat *a);
+
+    /**
+     * GIMarshallingTestsObjectClass::vfunc_multiple_inout_parameters:
+     * @a: (inout):
+     * @b: (inout):
+     */
+    void  (* vfunc_multiple_inout_parameters) (GIMarshallingTestsObject *self, gfloat *a, gfloat *b);
+
     /**
      * GIMarshallingTestsObjectClass::vfunc_caller_allocated_out_parameter:
      * @a: (out):
@@ -1434,6 +1447,19 @@ struct _GIMarshallingTestsObjectClass
      */
     glong (* vfunc_return_value_and_multiple_out_parameters) (GIMarshallingTestsObject *self, glong *a, glong *b);
 
+    /**
+     * GIMarshallingTestsObjectClass::vfunc_return_value_and_one_inout_parameter:
+     * @a: (inout):
+     */
+    glong (* vfunc_return_value_and_one_inout_parameter) (GIMarshallingTestsObject *self, glong *a);
+
+    /**
+     * GIMarshallingTestsObjectClass::vfunc_return_value_and_multiple_inout_parameters:
+     * @a: (inout):
+     * @b: (inout):
+     */
+    glong (* vfunc_return_value_and_multiple_inout_parameters) (GIMarshallingTestsObject *self, glong *a, glong *b);
+
     /**
      * GIMarshallingTestsObjectClass::vfunc_meth_with_err:
      * @x:
@@ -1560,6 +1586,12 @@ void gi_marshalling_tests_object_vfunc_one_out_parameter (GIMarshallingTestsObje
 _GI_TEST_EXTERN
 void gi_marshalling_tests_object_vfunc_multiple_out_parameters (GIMarshallingTestsObject *self, gfloat *a, gfloat *b);
 
+_GI_TEST_EXTERN
+void gi_marshalling_tests_object_vfunc_one_inout_parameter (GIMarshallingTestsObject *self, gfloat *a);
+
+_GI_TEST_EXTERN
+void gi_marshalling_tests_object_vfunc_multiple_inout_parameters (GIMarshallingTestsObject *self, gfloat *a, gfloat *b);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_object_vfunc_caller_allocated_out_parameter (GIMarshallingTestsObject *self, GValue *a);
 
@@ -1572,6 +1604,12 @@ glong gi_marshalling_tests_object_vfunc_return_value_and_one_out_parameter (GIMa
 _GI_TEST_EXTERN
 glong gi_marshalling_tests_object_vfunc_return_value_and_multiple_out_parameters (GIMarshallingTestsObject *self, glong *a, glong *b);
 
+_GI_TEST_EXTERN
+glong gi_marshalling_tests_object_vfunc_return_value_and_one_inout_parameter (GIMarshallingTestsObject *self, glong *a);
+
+_GI_TEST_EXTERN
+glong gi_marshalling_tests_object_vfunc_return_value_and_multiple_inout_parameters (GIMarshallingTestsObject *self, glong *a, glong *b);
+
 _GI_TEST_EXTERN
 gboolean gi_marshalling_tests_object_vfunc_meth_with_error (GIMarshallingTestsObject *object, gint x, GError **error);
 
